==> zio-aws-sagemakerruntime_2.12-7.21.15.5-sources.jar: zio/aws/sagemakerruntime/model/InvokeEndpointWithResponseStreamRequest.scala <==
package zio.aws.sagemakerruntime.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemakerruntime.model.primitives.{
  TargetVariantHeader,
  InferenceId,
  EndpointName,
  TargetContainerHostnameHeader,
  CustomAttributesHeader,
  BodyBlob,
  Header
}
import scala.jdk.CollectionConverters._
final case class InvokeEndpointWithResponseStreamRequest(
    endpointName: EndpointName,
    body: BodyBlob,
    contentType: Optional[Header] = Optional.Absent,
    accept: Optional[Header] = Optional.Absent,
    customAttributes: Optional[CustomAttributesHeader] = Optional.Absent,
    targetVariant: Optional[TargetVariantHeader] = Optional.Absent,
    targetContainerHostname: Optional[TargetContainerHostnameHeader] =
      Optional.Absent,
    inferenceId: Optional[InferenceId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest = {
    import InvokeEndpointWithResponseStreamRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest
      .builder()
      .endpointName(EndpointName.unwrap(endpointName): java.lang.String)
      .body(
        software.amazon.awssdk.core.SdkBytes.fromByteArrayUnsafe(
          body.toArray[Byte]
        )
      )
      .optionallyWith(
        contentType.map(value => Header.unwrap(value): java.lang.String)
      )(_.contentType)
      .optionallyWith(
        accept.map(value => Header.unwrap(value): java.lang.String)
      )(_.accept)
      .optionallyWith(
        customAttributes.map(value =>
          CustomAttributesHeader.unwrap(value): java.lang.String
        )
      )(_.customAttributes)
      .optionallyWith(
        targetVariant.map(value =>
          TargetVariantHeader.unwrap(value): java.lang.String
        )
      )(_.targetVariant)
      .optionallyWith(
        targetContainerHostname.map(value =>
          TargetContainerHostnameHeader.unwrap(value): java.lang.String
        )
      )(_.targetContainerHostname)
      .optionallyWith(
        inferenceId.map(value => InferenceId.unwrap(value): java.lang.String)
      )(_.inferenceId)
      .build()
  }
  def asReadOnly
      : zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest.ReadOnly =
    zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest
      .wrap(buildAwsValue())
}
object InvokeEndpointWithResponseStreamRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest =
      zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest(
        endpointName,
        body,
        contentType.map(value => value),
        accept.map(value => value),
        customAttributes.map(value => value),
        targetVariant.map(value => value),
        targetContainerHostname.map(value => value),
        inferenceId.map(value => value)
      )
    def endpointName: EndpointName
    def body: BodyBlob
    def contentType: Optional[Header]
    def accept: Optional[Header]
    def customAttributes: Optional[CustomAttributesHeader]
    def targetVariant: Optional[TargetVariantHeader]
    def targetContainerHostname: Optional[TargetContainerHostnameHeader]
    def inferenceId: Optional[InferenceId]
    def getEndpointName: ZIO[Any, Nothing, EndpointName] =
      ZIO.succeed(endpointName)
    def getBody: ZIO[Any, Nothing, BodyBlob] = ZIO.succeed(body)
    def getContentType: ZIO[Any, AwsError, Header] =
      AwsError.unwrapOptionField("contentType", contentType)
    def getAccept: ZIO[Any, AwsError, Header] =
      AwsError.unwrapOptionField("accept", accept)
    def getCustomAttributes: ZIO[Any, AwsError, CustomAttributesHeader] =
      AwsError.unwrapOptionField("customAttributes", customAttributes)
    def getTargetVariant: ZIO[Any, AwsError, TargetVariantHeader] =
      AwsError.unwrapOptionField("targetVariant", targetVariant)
    def getTargetContainerHostname
        : ZIO[Any, AwsError, TargetContainerHostnameHeader] = AwsError
      .unwrapOptionField("targetContainerHostname", targetContainerHostname)
    def getInferenceId: ZIO[Any, AwsError, InferenceId] =
      AwsError.unwrapOptionField("inferenceId", inferenceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest
  ) extends zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest.ReadOnly {
    override val endpointName: EndpointName =
      zio.aws.sagemakerruntime.model.primitives
        .EndpointName(impl.endpointName())
    override val body: BodyBlob = zio.aws.sagemakerruntime.model.primitives
      .BodyBlob(zio.Chunk.fromArray(impl.body().asByteArrayUnsafe()))
    override val contentType: Optional[Header] = zio.aws.core.internal
      .optionalFromNullable(impl.contentType())
      .map(value => zio.aws.sagemakerruntime.model.primitives.Header(value))
    override val accept: Optional[Header] = zio.aws.core.internal
      .optionalFromNullable(impl.accept())
      .map(value => zio.aws.sagemakerruntime.model.primitives.Header(value))
    override val customAttributes: Optional[CustomAttributesHeader] =
      zio.aws.core.internal
        .optionalFromNullable(impl.customAttributes())
        .map(value =>
          zio.aws.sagemakerruntime.model.primitives
            .CustomAttributesHeader(value)
        )
    override val targetVariant: Optional[TargetVariantHeader] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targetVariant())
        .map(value =>
          zio.aws.sagemakerruntime.model.primitives.TargetVariantHeader(value)
        )
    override val targetContainerHostname
        : Optional[TargetContainerHostnameHeader] = zio.aws.core.internal
      .optionalFromNullable(impl.targetContainerHostname())
      .map(value =>
        zio.aws.sagemakerruntime.model.primitives
          .TargetContainerHostnameHeader(value)
      )
    override val inferenceId: Optional[InferenceId] = zio.aws.core.internal
      .optionalFromNullable(impl.inferenceId())
      .map(value =>
        zio.aws.sagemakerruntime.model.primitives.InferenceId(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest
  ): zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-sagemakerruntime_3-7.21.15.8-sources.jar: zio/aws/sagemakerruntime/model/InvokeEndpointWithResponseStreamRequest.scala <==
package zio.aws.sagemakerruntime.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemakerruntime.model.primitives.{
  TargetVariantHeader,
  InferenceId,
  EndpointName,
  TargetContainerHostnameHeader,
  CustomAttributesHeader,
  BodyBlob,
  Header
}
import scala.jdk.CollectionConverters.*
final case class InvokeEndpointWithResponseStreamRequest(
    endpointName: EndpointName,
    body: BodyBlob,
    contentType: Optional[Header] = Optional.Absent,
    accept: Optional[Header] = Optional.Absent,
    customAttributes: Optional[CustomAttributesHeader] = Optional.Absent,
    targetVariant: Optional[TargetVariantHeader] = Optional.Absent,
    targetContainerHostname: Optional[TargetContainerHostnameHeader] =
      Optional.Absent,
    inferenceId: Optional[InferenceId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest = {
    import InvokeEndpointWithResponseStreamRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest
      .builder()
      .endpointName(EndpointName.unwrap(endpointName): java.lang.String)
      .body(
        software.amazon.awssdk.core.SdkBytes.fromByteArrayUnsafe(
          body.toArray[Byte]
        )
      )
      .optionallyWith(
        contentType.map(value => Header.unwrap(value): java.lang.String)
      )(_.contentType)
      .optionallyWith(
        accept.map(value => Header.unwrap(value): java.lang.String)
      )(_.accept)
      .optionallyWith(
        customAttributes.map(value =>
          CustomAttributesHeader.unwrap(value): java.lang.String
        )
      )(_.customAttributes)
      .optionallyWith(
        targetVariant.map(value =>
          TargetVariantHeader.unwrap(value): java.lang.String
        )
      )(_.targetVariant)
      .optionallyWith(
        targetContainerHostname.map(value =>
          TargetContainerHostnameHeader.unwrap(value): java.lang.String
        )
      )(_.targetContainerHostname)
      .optionallyWith(
        inferenceId.map(value => InferenceId.unwrap(value): java.lang.String)
      )(_.inferenceId)
      .build()
  }
  def asReadOnly
      : zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest.ReadOnly =
    zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest
      .wrap(buildAwsValue())
}
object InvokeEndpointWithResponseStreamRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest =
      zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest(
        endpointName,
        body,
        contentType.map(value => value),
        accept.map(value => value),
        customAttributes.map(value => value),
        targetVariant.map(value => value),
        targetContainerHostname.map(value => value),
        inferenceId.map(value => value)
      )
    def endpointName: EndpointName
    def body: BodyBlob
    def contentType: Optional[Header]
    def accept: Optional[Header]
    def customAttributes: Optional[CustomAttributesHeader]
    def targetVariant: Optional[TargetVariantHeader]
    def targetContainerHostname: Optional[TargetContainerHostnameHeader]
    def inferenceId: Optional[InferenceId]
    def getEndpointName: ZIO[Any, Nothing, EndpointName] =
      ZIO.succeed(endpointName)
    def getBody: ZIO[Any, Nothing, BodyBlob] = ZIO.succeed(body)
    def getContentType: ZIO[Any, AwsError, Header] =
      AwsError.unwrapOptionField("contentType", contentType)
    def getAccept: ZIO[Any, AwsError, Header] =
      AwsError.unwrapOptionField("accept", accept)
    def getCustomAttributes: ZIO[Any, AwsError, CustomAttributesHeader] =
      AwsError.unwrapOptionField("customAttributes", customAttributes)
    def getTargetVariant: ZIO[Any, AwsError, TargetVariantHeader] =
      AwsError.unwrapOptionField("targetVariant", targetVariant)
    def getTargetContainerHostname
        : ZIO[Any, AwsError, TargetContainerHostnameHeader] = AwsError
      .unwrapOptionField("targetContainerHostname", targetContainerHostname)
    def getInferenceId: ZIO[Any, AwsError, InferenceId] =
      AwsError.unwrapOptionField("inferenceId", inferenceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest
  ) extends zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest.ReadOnly {
    override val endpointName: EndpointName =
      zio.aws.sagemakerruntime.model.primitives
        .EndpointName(impl.endpointName())
    override val body: BodyBlob = zio.aws.sagemakerruntime.model.primitives
      .BodyBlob(zio.Chunk.fromArray(impl.body().asByteArrayUnsafe()))
    override val contentType: Optional[Header] = zio.aws.core.internal
      .optionalFromNullable(impl.contentType())
      .map(value => zio.aws.sagemakerruntime.model.primitives.Header(value))
    override val accept: Optional[Header] = zio.aws.core.internal
      .optionalFromNullable(impl.accept())
      .map(value => zio.aws.sagemakerruntime.model.primitives.Header(value))
    override val customAttributes: Optional[CustomAttributesHeader] =
      zio.aws.core.internal
        .optionalFromNullable(impl.customAttributes())
        .map(value =>
          zio.aws.sagemakerruntime.model.primitives
            .CustomAttributesHeader(value)
        )
    override val targetVariant: Optional[TargetVariantHeader] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targetVariant())
        .map(value =>
          zio.aws.sagemakerruntime.model.primitives.TargetVariantHeader(value)
        )
    override val targetContainerHostname
        : Optional[TargetContainerHostnameHeader] = zio.aws.core.internal
      .optionalFromNullable(impl.targetContainerHostname())
      .map(value =>
        zio.aws.sagemakerruntime.model.primitives
          .TargetContainerHostnameHeader(value)
      )
    override val inferenceId: Optional[InferenceId] = zio.aws.core.internal
      .optionalFromNullable(impl.inferenceId())
      .map(value =>
        zio.aws.sagemakerruntime.model.primitives.InferenceId(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest
  ): zio.aws.sagemakerruntime.model.InvokeEndpointWithResponseStreamRequest.ReadOnly =
    new Wrapper(impl)
}
